@@ -1,6 +1,6 @@
 /// This module contains everything needed from sqlx to set up a database connection or pool.
 /// Using this module, it is optional to directly depend on the `sqlx` crate.
-pub use sqlx::Connection;
+pub use sqlx::{query, query_as, Connection, Database, Executor};
 
 #[cfg(feature = "postgres")]
 pub use sqlx::postgres::{PgConnectOptions, PgConnection, PgPool, PgPoolOptions};
