@@ -1,3 +1,6 @@
+#![cfg_attr(feature = "insert", feature(inherent_associated_types))]
+
+pub use ormlite_core::BoxFuture;
 pub use ormlite_core::SelectQueryBuilder;
 pub use ormlite_core::{Error, Result};
 pub use ormlite_macro::Model;
